# Thanks to malcolmlewis for help with this script
# Thanks to Tom "spot" Callaway for much of the patchwork
# Thanks to jhaygood for most of the icu patch

%define pkgname chromium

#% define with_system_jpeg 1

#% define with_system_icu 1
#% define with_system_v8 1
%define with_system_vpx 1

#NOTE: src/third_party/ffmpeg/ffmpeg.gyp: 
# There's a couple key GYP variables that control how FFmpeg is built:
#   ffmpeg_branding
#     Controls whether we build the Chromium or Google Chrome version of
#     FFmpeg.  The Google Chrome version contains additional codecs.
#     Typical values are Chromium, Chrome, ChromiumOS, and ChromeOS.
#   use_system_ffmpeg
#     When set to non-zero will build Chromium against the system FFmpeg
#     headers via pkg-config.  When Chromium is launched it will assume that
#     FFmpeg is present in the system library path.  Default value is 0.
#   build_ffmpegsumo
#     When set to zero will build Chromium against the patched ffmpegsumo
#     headers, but not build ffmpegsumo itself.  Users are expected to build
#     and provide their own version of ffmpegsumo.  Default value is 1.
%define with_system_ffmpeg 1

%global chrome_sandbox %{_prefix}/lib/chrome_sandbox

Name:           chromium
Summary:        Google's opens source browser project
Summary(ja):    Googleのオープンソースウェブブラウザ
#'
Version:        22.0.1229.94
Release:        1%{?_dist_release}
License:        BSD-3-Clause, LGPL-2.1+
Group:          Applications/Internet
Source0:        %{pkgname}-%{version}.tar.xz
# Script used to create the %{pkgname}-%{version}.tar.xz archive from 
# a official tarball: 
# http://gsdview.appspot.com/chromium-browser-official/chromium-21.0.1180.XXX.tar.bz2
Source3:        pack_chromium21_source-vine.sh
# Patch template which adds vendor to user agent
##!!Source20:       chromium-vendor.patch.in
Source20:       chromium-vendor-vine.patch.in
# Set default prefs
##!!Source30:       master_preferences
Source30:       master_preferences.vine
##!!Source31:       default_bookmarks.html
#Source31:       default_bookmarks.html.vine
Source99:       chrome-wrapper
##!!Source100:      chromium-browser.sh
Source100:      chromium-browser-vine.sh
##!!Source101:      chromium-browser.desktop
Source101:      chromium-browser-vine.desktop
Source102:      chromium-browser.xml
#Source103:      chromium-browser-rpmlintrc
##!!Source104:      chromium-icons.tar.bz2

%{?nosrc:NoSource: 0}

# Provides:       chromium-unstable = %{version}-%{release}
# Obsoletes:      chromium13 chromium14 chromium15
# Conflicts:      chromium-stable
Provides:       chromium-stable = %{version}-%{release}
Conflicts:      chromium-unstable

## Start Patches
# OpenSuse and Fedora
# Many changes to the gyp systems so we can use system libraries
Patch1:         chromium-gcc46.patch
Patch8:         chromium-codechanges-zlib.patch
Patch13:        chromium-no-courgette.patch
Patch14:        chromium-master-prefs-path.patch
Patch17:        chromium-system-glew.patch
Patch18:        chromium-system-expat.patch
Patch20:        chromium-6.0.425.0-ffmpeg-no-pkgconfig.patch
Patch25:        tcmalloc-factory.patch
Patch26:        chromium-remoting-build-fix.diff
Patch28:        chromium-22.0.1229.94-system-speex.patch
Patch32:        chromium-7.0.542.0-system-libvpx.patch
Patch62:        chromium-norpath.patch
Patch63:        chromium-6.0.406.0-system-gyp-v8.patch
Patch64:        chromium-more-codec-aliases.patch
Patch66:        chromium-sandbox-pie.patch
Patch67:        chromium_use_gold.patch
Patch68:        chromium-gcc47.patch
# Upstream Patches 
#Patch500:       sqlite-3.7.6.3-fix-out-of-scope-memory-reference.patch


# Vine
#Patch100:       chromium-15.0.874.116-no-tests.patch


##!!BuildRequires:  Mesa-devel
BuildRequires:  mesa-libGLU-devel
##!!BuildRequires:  alsa-devel 
BuildRequires:  alsa-lib-devel
BuildRequires:  pulseaudio-libs-devel
BuildRequires:  bison
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  freetype2-devel
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gperf
BuildRequires:  hunspell-devel
##!!BuildRequires:  libbz2-devel 
BuildRequires:  bzip2-devel
BuildRequires:  libevent
##!!BuildRequires:  libexpat-devel
BuildRequires:  expat-devel
##!!BuildRequires:  libgnutls-devel
BuildRequires:  gnutls-devel
%{?with_system_jpeg:BuildRequires:  libjpeg-devel}
BuildRequires:  libpng-devel
BuildRequires:  libstdc++-devel >= 4.4
%{?with_system_vpx:BuildRequires:  libvpx-devel >= 0.9.5}
BuildRequires:  libxslt-devel
BuildRequires:  libzip-devel
##!!BuildRequires:  lzma
BuildRequires:  xz
##!!BuildRequires:  mozilla-nspr-devel
BuildRequires:  nspr-devel
##!!BuildRequires:  mozilla-nss-devel
BuildRequires:  nss-devel
BuildRequires:  krb5-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
##!!BuildRequires:  pkg-config
BuildRequires:  subversion
##!!BuildRequires:  perl(Switch)
BuildRequires:  perl
BuildRequires:  cairo-devel >= 1.6
BuildRequires:  dbus-devel
BuildRequires:  dbus-glib-devel
##!!BuildRequires:  gconf2-devel
BuildRequires:  GConf2-devel
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
BuildRequires:  libxml2-devel
BuildRequires:  python
##!!BuildRequires:  python-xml
BuildRequires:  python-pyxml
BuildRequires:  sqlite3-devel
##!!BuildRequires:  update-desktop-files
%{?with_system_v8:BuildRequires:  v8-devel = %{v8_ver}}
##!!BuildRequires:  wdiff
BuildRequires:  zlib-devel
##!!BuildRequires:  libpulse-devel
BuildRequires:  pulseaudio-libs-devel
##!!BuildRequires:  libelf-devel
BuildRequires:  elfutils-libelf-devel
BuildRequires:  libgnome-keyring-devel
BuildRequires:  python-devel
#BuildRequires:  glew-devel
BuildRequires:  libevent-devel
%{?with_system_icu:BuildRequires:  libicu-devel >= 4.0}
#BuildRequires:  libjingle-devel >= 0.4.0-7
#BuildRequires:  srtp-devel
BuildRequires:  speex-devel
BuildRequires:  libudev-devel

##Vine Linux
#BuildRequires:  libpaper-devel
BuildRequires:  libXScrnSaver-devel
BuildRequires:  libXtst-devel
BuildRequires:  libXdamage-devel
BuildRequires:  libXt-devel
#%ifarch x86_64
#Requires:  nspluginwrapper
#%endif

##!!Requires:       alsa
Requires:       alsa-lib
Requires:       pulseaudio-libs
Requires:       xdg-utils
%{?with_system_v8:Requires:       v8 = %{v8_ver}}

BuildRoot:      %{_tmppath}/%{name}-%{version}-root

%description
Chromium is the open-source project behind Google Chrome. 
We invite you to join us in our effort to help build a safer, faster, 
and more stable way for all Internet users to experience the web, 
and to create a powerful platform for developing a new generation of 
web applications.

%description -l ja
Chromium は Google Chrome の後方にあるオープンソースプロジェクトです。
ウェブを体験しているすべてのインターネットユーザに対して
より安全で、より速くて、より安定した方法を築き上げるのを補助するでしょう。
そして、ウェブアプリケーションの新しい世代を発展させ、
強力なプラットホームを作成するために、
私たちの取り組みにぜひ参加してください。


%prep
#%setup -q
[ -d %{pkgname}-%{version} ] && %__rm -rf %{pkgname}-%{version}
xz -dc %{SOURCE0} | %__tar -xf - || exit 1
%setup -D -T -n %{pkgname}-%{version}

%if %{?_dist_release} == "vl7"
%patch1 -p1
%endif
%patch62 -p1
%{?with_system_v8:%patch63 -p1}
%patch64
#%patch65 -p1
#%patch100 -p1 -b .vine
%patch8 -p1
%patch13 -p1
%patch14 -p1
%patch17 -p1
%patch18 -p1
%{?with_system_ffmpeg:%patch20 -p1}
#%patch25 -p1
%patch26 -p1
%patch28 -p1
%{?with_system_vpx:%patch32 -p1}
%patch66 -p1
#%patch67 -p1
#%patch68 -p1
#%patch500 -p1


# apply vendor patch after substitution
%__sed "s:RPM_VERSION:%{version}-%{release}:" %{SOURCE20} | patch -p0

# Make sure that the requires legal files can be found
%__cp -a src/AUTHORS src/LICENSE . || exit 1

%build

## create make files

PARSED_OPT_FLAGS=`echo \'$RPM_OPT_FLAGS -DUSE_SYSTEM_LIBEVENT -fPIC -fno-ipa-cp -fno-strict-aliasing \' | %__sed "s/ /',/g" | %__sed "s/',/', '/g"`
for i in src/build/common.gypi; do
        %__sed -i "s|'-march=pentium4',||g" $i
        %__sed -i "s|'-mfpmath=sse',||g" $i
        %__sed -i "s|'-O<(debug_optimize)',||g" $i
        %__sed -i "s|'-m32',||g" $i
        %__sed -i "s|'-fno-exceptions',|$PARSED_OPT_FLAGS|g" $i
        %__sed -i "s|'-Werror'|'-Wno-error'|g" $i
done
# '

pushd src

./build/gyp_chromium -f make build/all.gyp \
    -Dlinux_sandbox_path=%{chrome_sandbox} \
    -Dlinux_sandbox_chrome_path=%{_libdir}/chromium/chromium \
    -Duse_openssl=0 \
    %{?with_system_ffmpeg:-Duse_system_ffmpeg=1} \
    %{!?with_system_ffmpeg:-Duse_system_ffmpeg=0} \
    -Dbuild_ffmpegsumo=1 \
    -Duse_system_zlib=1 \
    -Duse_system_libpng=1 \
    -Duse_system_bzip2=1 \
    -Duse_system_libbz2=1 \
    %{?with_system_jpeg:-Duse_system_libjpeg=1} \
    %{!?with_system_jpeg:-Duse_system_libjpeg=0} \
    -Duse_system_libxml=1 \
    -Duse_system_libxslt=1 \
    -Duse_system_libevent=1 \
    %{?with_system_vpx:-Duse_system_vpx=1} \
    %{!?with_system_vpx:-Duse_system_vpx=0} \
    -Dremove_webcore_debug_symbols=1 \
    %{?with_system_v8:-Duse_system_v8=1} \
    %{!?with_system_v8:-Duse_system_v8=0} \
    %{?with_system_icu:-Duse_system_icu=1} \
    %{!?with_system_icu:-Duse_system_icu=0} \
    %{?_with_shared_library:-Dlibrary=shared_library} \
    -Dproprietary_codecs=1 \
    -Ddisable_nacl=1 \
    -Dlinux_use_gold_flags=0 \
    -Dlinux_use_gold_binary=0 \
    -Djavascript_engine=v8 \
    -Dlinux_fpic=1 \
    -Ddisable_sse2=1 \
    %ifarch %{ix86}
        -Dtarget_arch=ia32 \
    %endif
    %ifarch x86_64
        -Dtarget_arch=x64 \
    %endif
    -Dno_strict_aliasing=1 \
    -Drelease_extra_cflags=-fPIC \
    %if %{?_dist_release} == "vl6"
        -Dgcc_version=44 \
    %endif
    ;

%__make -r %{?_smp_mflags} chrome V=1 BUILDTYPE=Release disable_nacl=1

# Build the required SUID_SANDBOX helper
%__make -r %{?_smp_mflags} chrome_sandbox V=1 BUILDTYPE=Release disable_nacl=1

# Build the ChromeDriver test suite
%__make -r %{?_smp_mflags} chromedriver V=1 BUILDTYPE=Release disable_nacl=1
popd

%install
%{__rm} -rf %{buildroot}

%__mkdir_p %{buildroot}%{_bindir}
%__install -m 755 %{SOURCE100} %{buildroot}%{_bindir}/chromium
%ifarch x86_64
%__mkdir_p %{buildroot}%{_prefix}/lib/
%endif
# x86_64 capable systems need this
%__sed -i "s|/usr/lib/chromium|%{_libdir}/chromium|g" %{buildroot}%{_bindir}/chromium
%__mkdir_p %{buildroot}%{_libdir}/chromium/
%__mkdir_p %{buildroot}%{_mandir}/man1/
pushd src/out/Release
%__cp -a chrome_sandbox %{buildroot}%{_prefix}/lib/ || exit 1
%__cp -a chrome.pak locales resources xdg-mime xdg-settings %{buildroot}%{_libdir}/chromium/ || exit 1
%__cp -a chromedriver %{buildroot}%{_libdir}/chromium/ || exit 1
%__cp -a content_resources.pak theme_resources_100_percent.pak ui_resources_100_percent.pak  %{buildroot}%{_libdir}/chromium/ || exit 1
%__cp -a resources.pak %{buildroot}%{_libdir}/chromium/ || exit 1
%__cp -a chrome %{buildroot}%{_libdir}/chromium/chromium || exit 1
%{?_with_shared_library:%__cp -a lib.target/lib*.so %{buildroot}%{_libdir}/chromium/ || exit 1}
%{?_with_shared_library:%__cp -a lib.host/lib*.so %{buildroot}%{_libdir}/chromium/ || exit 1}
%__cp -a chrome.1 %{buildroot}%{_mandir}/man1/chrome.1 || exit 1
%__cp -a chrome.1 %{buildroot}%{_mandir}/man1/chromium.1 || exit 1
fdupes %{buildroot}%{_mandir}/man1/
popd

%__mkdir_p %{buildroot}%{_datadir}/pixmaps/
%__cp -a src/chrome/app/theme/chromium/product_logo_48.png %{buildroot}%{_datadir}/pixmaps/chromium-browser.png
for i in 22 24 48 64 128 256; do
    %__mkdir_p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps
    %__cp -a src/chrome/app/theme/chromium/product_logo_${i}.png %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/chromium-browser.png || exit 1
done

%__mkdir_p %{buildroot}%{_datadir}/applications/
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{SOURCE101}

%__mkdir_p %{buildroot}%{_datadir}/gnome-control-center/default-apps/
%__cp -a %{SOURCE102} %{buildroot}%{_datadir}/gnome-control-center/default-apps/

# # link to browser plugin path.  Plugin patch doesn't work. Why?
# %{__mkdir_p} %{buildroot}%{_libdir}/browser-plugins
# pushd %{buildroot}%{_libdir}/%{pkgname}
# %{__ln_s} %{_libdir}/browser-plugins plugins
# popd
pushd %{buildroot}%{_libdir}/%{pkgname}
#%ifarch x86_64
#%{__ln_s} %{_libdir}/mozilla/plugins-wrapped plugins || exit 1
#%else
%{__ln_s} %{_libdir}/mozilla/plugins plugins || exit 1
#%endif
popd

# Install the master_preferences file
%__mkdir_p %{buildroot}%{_sysconfdir}/%{pkgname}
#%__install -m 0644 %{SOURCE30} %{buildroot}%{_sysconfdir}/%{pkgname}
%__install -m 0644 %{SOURCE30} %{buildroot}%{_sysconfdir}/%{pkgname}/$(basename %{SOURCE30} .vine)
#%__install -m 0644 %{SOURCE31} %{buildroot}%{_sysconfdir}/%{pkgname}

%clean
%{__rm} -rf %{buildroot}

%post
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi 
%{_bindir}/update-desktop-database --quiet %{_datadir}/applications || :

%postun
%{_bindir}/update-desktop-database --quiet %{_datadir}/applications
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi || :


%files
%defattr(-,root,root,-)
%config %{_sysconfdir}/%{pkgname}
%dir %{_datadir}/gnome-control-center
%dir %{_datadir}/gnome-control-center/default-apps
%dir %{_libdir}/chromium/
%{_bindir}/chromium
%{_libdir}/chromium/chromium
%{_libdir}/chromium/plugins/
%{_libdir}/chromium/locales/
%{_libdir}/chromium/resources/
#%{_libdir}/chromium/nacl_*
#%{_libdir}/chromium/libppGoogleNaClPluginChrome.so
%attr(755,root,root) %{_libdir}/chromium/xdg-settings
%attr(755,root,root) %{_libdir}/chromium/xdg-mime
%{_libdir}/chromium/*.pak
%{_mandir}/man1/chrom*
%{_datadir}/applications/*.desktop
%{_datadir}/gnome-control-center/default-apps/chromium-browser.xml
%{_datadir}/pixmaps/chromium-browser.png
%{_datadir}/icons/hicolor/*/apps/chromium-browser.png
%{?_with_shared_library:%{_libdir}/chromium/lib*.so}
%attr(4755,root,root) %{chrome_sandbox}
%{_libdir}/chromium/chromedriver


%changelog
* Mon Oct 15 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 22.0.1229.94-1
- update to 22.0.1229.94

* Sun Sep  2 2012 Munehiro Yamamoto <munepi@vinelinux.org> 21.0.1180.89-1
- updated to 21.0.1180.89

* Sun Aug 26 2012 Munehiro Yamamoto <munepi@vinelinux.org> 21.0.1180.84-1
- updated to 21.0.1180.84

* Fri Aug 10 2012 Munehiro Yamamoto <munepi@vinelinux.org> 21.0.1180.78-1
- updated to 21.0.1180.78
- dropped Requires: nspluginwrapper

* Thu Jun 28 2012 Munehiro Yamamoto <munepi@vinelinux.org> 20.0.1132.54-1
- updated to 20.0.1132.54

* Sun Jun 10 2012 Munehiro Yamamoto <munepi@vinelinux.org> 19.0.1084.57-1
- updated to 19.0.1084.57

* Sat Jun  2 2012 Munehiro Yamamoto <munepi@vinelinux.org> 19.0.1084.53-1
- updated to 19.0.1084.53

* Tue May 22 2012 Munehiro Yamamoto <munepi@vinelinux.org> 19.0.1084.50-1
- updated to 19.0.1084.50

* Tue May  8 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.169-1
- updated to 18.0.1025.169

* Sat Apr 28 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.166-1
- updated to 18.0.1025.166

* Sat Apr 14 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.163-1
- updated to 18.0.1025.163

* Tue Apr  3 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.148-1
- updated to 18.0.1025.148

* Wed Mar 28 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.145-1
- updated to 18.0.1025.145

* Sun Mar 25 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.140-1
- updated to 18.0.1025.140

* Thu Mar 22 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.130-1
- updated to 18.0.1025.130

* Tue Mar 20 2012 Munehiro Yamamoto <munepi@vinelinux.org> 18.0.1025.114-1
- updated to 18.0.1025.114

* Tue Mar 20 2012 Munehiro Yamamoto <munepi@vinelinux.org> 17.0.963.81-1
- updated to 17.0.963.81

* Fri Mar  9 2012 Munehiro Yamamoto <munepi@vinelinux.org> 17.0.963.78-1
- updated to 17.0.963.78

* Sat Mar  3 2012 Munehiro Yamamoto <munepi@vinelinux.org> 17.0.963.65-1
- updated to 17.0.963.65

* Wed Feb 29 2012 Munehiro Yamamoto <munepi@vinelinux.org> 17.0.963.60-1
- updated to 17.0.963.60

* Fri Feb 17 2012 Munehiro Yamamoto <munepi@vinelinux.org> 17.0.963.57-1
- updated to 17.0.963.57

* Sun Feb 12 2012 Munehiro Yamamoto <munepi@vinelinux.org> 17.0.963.54-1
- updated to 17.0.963.54

* Sat Feb 11 2012 Munehiro Yamamoto <munepi@vinelinux.org> 17.0.963.52-1
- updated to 17.0.963.52

* Sat Feb  4 2012 Munehiro Yamamoto <munepi@vinelinux.org> 16.0.912.77-1
- updated to 16.0.912.77

* Sun Jan  8 2012 Munehiro Yamamoto <munepi@vinelinux.org> 16.0.912.75-1
- updated to 16.0.912.75

* Fri Dec 30 2011 Munehiro Yamamoto <munepi@vinelinux.org> 16.0.912.63-1
- updated to 16.0.912.63

* Thu Dec  1 2011 Munehiro Yamamoto <munepi@vinelinux.org> 16.0.912.57-1
- updated to 16.0.912.57

* Sat Oct 29 2011 Munehiro Yamamoto <munepi@vinelinux.org> 15.0.874.116-1
- updated to 15.0.874.116

* Wed Oct 12 2011 Munehiro Yamamoto <munepi@vinelinux.org> 14.0.835.204-1
- updated to 14.0.835.204
- added BuildRequires: dbus-glib-devel

* Sat Sep 24 2011 Munehiro Yamamoto <munepi@vinelinux.org> 14.0.835.186-1
- updated to 14.0.835.186

* Sun Sep 18 2011 Munehiro Yamamoto <munepi@vinelinux.org> 14.0.835.163-1
- updated to 14.0.835.163

* Tue Sep 06 2011 Munehiro Yamamoto <munepi@vinelinux.org> 14.0.835.157-1
- updated to 14.0.835.157

* Sat Aug 20 2011 Munehiro Yamamoto <munepi@vinelinux.org> 14.0.835.102-1
- updated to 14.0.835.102

* Sat Aug 13 2011 Munehiro Yamamoto <munepi@vinelinux.org> 14.0.835.89-1
- updated to 14.0.835.89
- added Obsoletes: chromium-unstable < %{version}-%{release}

* Wed Aug 10 2011 Munehiro Yamamoto <munepi@vinelinux.org> 14.0.835.35-1
- updated to 14.0.835.35
- added BuildRequires: pulseaudio-libs-devel, Requires: pulseaudio-libs
- changed to Name: chromium14
  - Provides:  chromium-unstable = %%{version}
  - Conflicts: chromium-stable

* Wed Aug 03 2011 Munehiro Yamamoto <munepi@vinelinux.org> 13.0.782.107-1
- changed to Name: chromium
- updated to 13.0.782.107

* Wed Jul 13 2011 Munehiro Yamamoto <munepi@vinelinux.org> 13.0.782.88-1
- updated to 13.0.782.88
- added BuildRequires: libzip-devel
- added Provides: chromium-unstable = %%{version}
- added Conflicts: chromium-stable

* Thu Jun 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 12.0.742.93-1
- fix user-agent string (chromium-vendor-vine.patch.in)
  - move vendor string (Vine/12.0.742.91-1vl6) to the end.

* Sat Jun 11 2011 Munehiro Yamamoto <munepi@vinelinux.org> 12.0.742.93-1
- updated to 12.0.742.93
- fixed icon field of chromium-browser-vine.desktop

* Wed Jun 08 2011 Munehiro Yamamoto <munepi@vinelinux.org> 12.0.742.91-1
- updated to 12.0.742.91

* Sun Jun 05 2011 Munehiro Yamamoto <munepi@vinelinux.org> 12.0.742.77-1
- updated to 12.0.742.77

* Sat May 21 2011 Munehiro Yamamoto <munepi@vinelinux.org> 12.0.742.63-1
- updated to 12.0.742.63

* Sun May 07 2011 Munehiro Yamamoto <munepi@vinelinux.org> 12.0.742.42-1
- updated to 12.0.742.42

* Sun Apr 23 2011 Munehiro Yamamoto <munepi@vinelinux.org> 12.0.742.6-1
- updated to 12.0.742.6
- dropped/upstreamed patches
- updated our no-tests patch (chromium-12.0.742.6-no-tests.patch)

* Wed Apr 13 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.50-1
- updated to 11.0.696.50
- dropped some Patches for MeeGo Netbook

* Tue Apr 05 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.35-1
- updated to 11.0.696.35

* Wed Mar 27 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.29-1
- updated to 11.0.696.29
- dropped "--no-first-run" in command line options of chromium-browser-vine.sh

* Thu Mar 24 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.22-1
- updated to 11.0.696.22
- improved chromium-browser-vine.sh
  - merged from chromium-browser-vine.desktop of 11.0.696.17-1

* Wed Mar 23 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.20-1
- updated to 11.0.696.20
- improved chromium-browser-vine.desktop

* Sun Mar 20 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.17-1
- updated to 11.0.696.17

* Sat Mar 19 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.15-1
- updated to 11.0.696.15
  - ready for Vine Linux 6 release
- dropped BuildRequires: v8-devel, libicu-devel

* Wed Mar 09 2011 Munehiro Yamamoto <munepi@vinelinux.org> 11.0.696.5-1
- updated to 11.0.696.5 with v8 3.2.0
- added BuildRequires: pam-devel

* Thu Feb 10 2011 Toshiharu Kudoh <toshi.kd2@gmail.com> 10.0.651.0-2
- rebuilt with libevent-2.0.10

* Sat Jan 29 2011 Munehiro Yamamoto <munepi@vinelinux.org> 10.0.651.0-1
- updated to 10.0.651.0 with v8 3.0.12
- added BuildRequires: 
  - libpaper-devel
  - python-devel
- added built header file: libavutil/avconfig.h %%prep
- unexport MOZ_PLUGIN_PATH in chromium-browser-vine.sh

* Sun Dec 26 2010 Munehiro Yamamoto <munepi@vinelinux.org> 10.0.622.0-1
- updated to 10.0.622.0
- added BuildRequires: libXt-devel

* Sat Dec 11 2010 Munehiro Yamamoto <munepi@vinelinux.org> 10.0.605.0-1
- updated to 10.0.605.0
- added BuildRequires: 
  - libXdamage-devel
  - hunspell-devel

* Sat Dec 04 2010 Munehiro Yamamoto <munepi@vinelinux.org> 9.0.598.0-1
- updated to 9.0.598

* Fri Nov 26 2010 Munehiro Yamamoto <munepi@vinelinux.org> 9.0.593.0-1
- updated to 9.0.593

* Thu Nov 11 2010 Munehiro Yamamoto <munepi@vinelinux.org> 9.0.582.0-1
- updated to 9.0.582
- added Requires: xdg-utils

* Thu Nov 11 2010 Munehiro Yamamoto <munepi@vinelinux.org> 9.0.578.0-1
- updated to 9.0.578

* Sat Oct 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 9.0.569.0-1
- updated to 9.0.569

  * Mon Oct 25 2010 tittiatcoke@gmail.com
  - Update to 9.0.564 build
    * Added specific patches for MeeGo.
    * We are now using shared libraries for Chromium
    * Spec-file cleanup (Thanks to prusnak)

* Sat Oct 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 8.0.556.0-1
- updated to snapshot 8.0.556

* Sun Oct 10 2010 Munehiro Yamamoto <munepi@vinelinux.org> 8.0.551.0-1
- updated to snapshot 8.0.551

* Fri Sep 17 2010 Munehiro Yamamoto <munepi@vinelinux.org> 7.0.527.0-1
- updated to snapshot 7.0.527

* Thu Sep 09 2010 Munehiro Yamamoto <munepi@vinelinux.org> 7.0.519.0-1
- updated to snapshot 7.0.519

* Fri Sep 03 2010 Munehiro Yamamoto <munepi@vinelinux.org> 7.0.513.0-1
- updated to snapshot 7.0.513
  - updated chromium-vendor-vine.patch.in

* Sat Aug 28 2010 Munehiro Yamamoto <munepi@vinelinux.org> 7.0.507.0-1
- updated to snapshot 7.0.507

* Wed Aug 18 2010 Munehiro Yamamoto <munepi@vinelinux.org> 7.0.498.0-1
- updated to snapshot 7.0.498

* Sat Aug 14 2010 Munehiro Yamamoto <munepi@vinelinux.org> 6.0.493.0-1
- updated to snapshot 6.0.493
- used with_system_icu (for vl6)
  - added BuildRequires: libicu-devel

* Thu Jul 22 2010 IWAI, Masaharu <iwai@alib.jp> 6.0.454.0-2vl5
- build for Vine Linux 5.x
  - add BuildRequires: gnome-keyring-devel

* Sat Jul 17 2010 Munehiro Yamamoto <munepi@vinelinux.org> 6.0.454.0-1
- updated to snapshot 6.0.454
- added BuildRequires: 
  - sqlite3-devel
  - gnutls-devel
  - libgnome-keyring-devel

* Sat Jun 12 2010 Munehiro Yamamoto <munepi@vinelinux.org> 6.0.431.0-1
- updated to snapshot 6.0.431.0 r49253
- added BuildRequires: cups-devel

* Sun May 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 6.0.405.0-1
- updated to snapshot 6.0.405.0 r47263

* Fri Apr 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.378.0-2
- unused with_system_icu (for vl6)
  - used icu-4.2.1-chromium.5.0.353.0.svn41449 (for vl6)

* Wed Apr 14 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.378.0-1
- updated to snapshot 5.0.378.0 r44472
  - used with_system_icu (for vl6)
  - added icu-4.2.1-chromium.5.0.353.0.svn41449.tar.bz2 (for vl5)

* Sat Apr 10 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.372.0-1
- updated to snapshot 5.0.372.0 r43947
- added BuildRequires: glew-devel
- changed Group tag to Applications/Internet
- added Summary(ja) and %%description -l ja 

* Mon Apr 05 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.365.0-1
- updated to snapshot 5.0.365.0 r42966
- merged 5.0.353.0-4vl5
 * Fri Apr  2 2010 IWAI, Masaharu <iwai@alib.jp> 5.0.353.0-4vl5
 - build on Vine Linux 5.1
   - add BuildRequires: libstdc++34 libstdc++34-devel for Vine5

* Sat Mar 27 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.364.0-1
- updated to snapshot 5.0.364.0 r42779

* Sun Mar 21 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.359.0-1
- updated to snapshot 5.0.359.0 r42116
- dropped chromium-20100122-ubuntu-html5-video-mimetypes.patch

* Tue Mar 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.353.0-4
- fixed master_preferences.vine, little

* Tue Mar 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.353.0-3
- fixed to install master_preferences
- dropped chromium-5.0.353-no-ffmpeg-vine.patch

* Tue Mar 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.353.0-2
- applied chromium-5.0.353-no-ffmpeg-vine.patch

* Tue Mar 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.353.0-1
- updated to snapshot 5.0.353.0 r41449
  * Wed Mar 10 2010 bgmerrell@novell.com
  - Add master_preferences source file and install it to /etc/chromium.
  - Create a new patch (chromium-master-prefs-path.patch) which tells
    chromium to look in /etc/chromium for the master_preferences file
    (instead of looking in the default directory, which is the same
    directory as the 'chrome' binary).

* Sun Feb 21 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.335.0-1
- updated to snapshot 5.0.335.0 r39556

* Sat Feb 20 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.330.0-2
- applied chromium-20100122-ubuntu-html5-video-mimetypes.patch from Gentoo

* Wed Feb 17 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.330.0-1
- updated to snapshot 5.0.330.0 r39074

* Wed Feb 17 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.329.0-5
- use_system_ffmpeg

* Tue Feb 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.329.0-4
- added Requires:  nspluginwrapper
- fixed a symbolic link of plugins directory with nspluginwrapper

* Tue Feb 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.329.0-3
- replaced %%{SOUECE20} to chromium-vendor-vine.patch.in

* Tue Feb 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.329.0-2
- added BuildRequires: mesa-libGLU-devel
- added BuildRequires: libstdc++34 libstdc++34-devel for vl5

* Tue Feb 16 2010 Munehiro Yamamoto <munepi@vinelinux.org> 5.0.329.0-1
- built based on chromium-5.0.329.0-167.1.src.rpm of OpenSuse

  * Sun Nov 29 2009 - tittiatcoke@gmail.com - 4.0.260.0
  - Update to 4.0.260
  * Fri Nov 27 2009 - tittiatcoke@gmail.com - 4.0.259.0
  - Update to 4.0.259
  * Thu Nov 26 2009 - tittiatcoke@gmail.com - 4.0.258.0
  - Update to 4.0.258
  * Tue Nov 24 2009 - tittatcoke@gmai.com - 4.0.257.0
  - In order to complete prevent the wrong v8 version to be used, the Chromium build has been
    changed to having an built-in v8 
  * Tue Nov 24 2009 - dbuck@example.com - 4.0.257.0
  - Re-base patches.  Fixed a few patch errors.  Rename some patches to better correspond with function.  Removed some patches.
  - Minor SPEC changes.  I changed the v8 requirement to be exact, instead of greater than a specific version.
  * Sat Oct 24 2009 - Pavol Rusnak <prusnak@suse.cz> - 4.0.223.5
  - don't create desktop files in wrapper, fix LD_LIBRARY_PATH (chromium-fix-wrapper.patch)
  * Tue Oct 20 2009 - Raymond Wooninck >tittiatcoke@gmail.com> - 4.0.223.5
  - update to newer svn snapshot
    + Obsoletes fwrite patch (included upstream)
  * Fri Oct 16 2009 - Raymond Wooninck <tittiatcoke@gmail.com> - 4.0.223.2
  - update to newer svn snapshot
    + Requires newer version of v8
  * Thu Oct 15 2009 - Pavol Rusnak <prusnak@suse.cz> - 4.0.222.6
  - do not force SSE on x86 (drop-sse.patch)
  * Tue Oct 13 2009 - Raymond Wooninck <tittiatcoke@gmail.com> - 4.0.222.6
  - Update to newer svn snapshot
  - Fixed spec file in order to build
  - Included patch to build with system zlib
  * Mon Oct 12 2009 - Pavol Rusnak <prusnak@suse.cz> 4.0.222.2
  - package renamed to chromium
  - cleaned up spec file
  * Tue Oct 6 2009 - dbuck <dbuck@example.com> - 4.0.222.2
  - v8 is now built as a separate package, and is required
  - included many patches to use system libraries: v8, icu, libxml2, libxslt, libjpeg, libpng, libevent, bzip2, zlib, nspr, nss
  * Sun Oct 1 2009 - dbuck <dbuck@example.com> - 4.0.221.1
  - included a newer DEP than is in svn, native_client@823.  So things should compile cleanly now
  * Sun Aug 31 2009 - dbuck <dbuck@example.com> - 4.0.204.0
  - initial build

#% changelog
* Sun Jan 24 2010 prusnak@suse.cz
- added vendor to user agent (chromium-vendor.patch.in)
* Sun Nov 29 2009 prusnak@suse.cz
- added --enable-sync to wrapper to enable bookmark sync
* Sun Nov 29 2009 tittiatcoke@gmail.com  
- Update to 4.0.260
* Fri Nov 27 2009 tittiatcoke@gmail.com  
- Update to 4.0.259
* Thu Nov 26 2009 tittiatcoke@gmail.com  
- Update to 4.0.258
* Tue Nov 24 2009 tittatcoke@gmai.com  
- In order to complete prevent the wrong v8 version to be used,
  the Chromium build has been changed to having an built-in v8
* Tue Nov 24 2009 dbuck@example.com  
- Re-base patches.
- Fixed a few patch errors.
- Rename some patches to better correspond with function.
- Removed some patches.
- Minor SPEC changes.
- I changed the v8 requirement to be exact, instead of greater than a specific version.
* Fri Nov 13 2009 tittiatcoke@gmail.com
- update to 247.0 svn 31928
* Fri Oct 30 2009 tittiatcoke@gmail.com
- update to 229.0 svn 30454
  + Fix regression where popups and app frames lost their titlebars.
  + Makes it so that when a folder is open on the bookmark bar
    and the mouse moves over another folder, the menu for that
    folder is shown.
  + Lazily create the find bar.
  + Polish to the gmail checker sample.
  * New, crisper icons that are exactly 19x19
  * Add a loading animation at the beginning before Gmail
    responds.
  * Fix a bug where we sometimes don't update the UI after a
    logout/login cycle.
  + Refactor widget methods to support desktop notifications,
    including GTK stubs.
  + Find-in-page should not ding while deleting characters.
  + Add SSL wrapper for linux and mac.  This allows notifier to
    use chrome's SSL layer instead of OpenSSL.
  + Add three of the six extensions to PAC that Internet Explorer supports.
  + WebSocket support in chromium. (Run with --enable-web-sockets
    enables WebSocket features.)
  + Do not allow GTK File Chooser dialogs to return directories.
  + Fix the notifier SSL layer to make notifications work for
    Linux Bookmark sync.
  + linux: don't override mouse selection behavior in omnibox
* Sun Oct 25 2009 tittiatcoke@gmail.com
- Update to 224.4 svn 30027
  + First cut at new page and browser action docs based
    on new API. Deleted old stuff.
  + Add suppression for new memory leak caused by WebKit merge 49830:49844
  + Cleanup: change PIDs to base::ProcessId (or pid_t, as appropriate)
  + Minimize dependency of user scripts
  + Fixup the flip_framer eof-handling semantics now that we have
    the FIN bit in place
  + app depends on x11 because of active_window_watcher_x
  + Adding two images for the new Extension managment UI
  + Removing hard-coded Chrome Frame output path
  + Rearrange clipboard code
  + Fix crash bug when attempting to download a url with unsupported scheme,
    e.g. 'data:', by 'Alt + Click'
  + GTK: Change text for extension download UI
  + Ignore invalid urls on command line
  + Make dropped tabs animate from where they were dropped.
  + Make room for the full width of the tab placeholder.
  + Make tab dragging as smooth as glass.
  + Remove an annoying NOTIMPLEMNETED
  + Extensions: guarantee removal of BROWSER_WINDOW_READY registration
  + If we're in the middle of a drag, don't allow the user to middle
    click to close or right click for the context menu
  + "Fix" a NOTIMPLEMENTED on Linux by using the default password store
  + Remove +x bit from files that shouldn't have it
  + Fold first 3 channels of multichannel instead of 5.  Use fixed point
  + Adding new image needed for the managment UI
  + Fix a race bug where content scripts would not apply to the first page load
  + Make escape remove a bookmark if it's just been added (but not if it already existed)
  + Fix bubbles deactivating the opaque frame
  + Allow ESC to cancel ALT+SHIFT+T in Toolbar
  + ake all pepper plugins default to windowless and transparent
  + Add styles for printing
  + Implement the new extension management UI
  + Add support for to automation interface load install and load extensions
  + GTK: theme the info bar border
  + Update V8 to version 1.3.16.1
  + Introduce WebSecurityPolicy for security related methods
  + New button scheme...borders are separate from the inner contents so
    that they can be highlighted / depressed independently
  + When opening Chrome maximized with an application window already
    running, the Chrome window was not activated
  + Fix compatibility problems with FileZilla FTP Server
  + Remove the extension shelf on Linux
  + Fix the proxy host and port string to start with http:// if it does not already
  + Enable HTML5 databases for all extension renderer processes
* Sat Oct 24 2009 prusnak@opensuse.org  
- don't create desktop files in wrapper
- fix LD_LIBRARY_PATH (chromium-fix-wrapper.patch)
* Tue Oct 20 2009 tittiatcoke@gmail.com  
- update to newer svn snapshot
  + Obsoletes fwrite patch (included upstream)
* Fri Oct 16 2009 tittiatcoke@gmail.com  
- update to newer svn snapshot
  + Requires newer version of v8
* Thu Oct 15 2009 prusnak@suse.cz  
- do not force SSE on x86 (drop-sse.patch)
* Tue Oct 13 2009 tittiatcoke@gmail.com  
- Update to newer svn snapshot
- Fixed spec file in order to build
- Included patch to build with system zlib
* Mon Oct 12 2009 prusnak@suse.cz  
- package renamed to chromium
- cleaned up spec file
* Tue Oct  6 2009 dbuck@example.com  
- v8 is now built as a separate package, and is required
- included many patches to use system libraries:
    v8, icu, libxml2, libxslt, libjpeg, libpng, libevent, bzip2, zlib, nspr, nss
* Thu Oct  1 2009 dbuck@example.com  
- included a newer DEP than is in svn, native_client@823
- things should compile cleanly now
* Mon Aug 31 2009 dbuck@example.com  
- initial build
