# Minimal required versions
%global nspr_version 4.8.9
%global nss_version 3.13.1
%global cairo_version 1.10.2
%global freetype_version 2.1.9
%global libnotify_version 0.7.0

# gecko_dir_ver should be set to the version in our directory names
# alpha_version should be set to the alpha number if using an alpha, 0 otherwise
# beta_version  should be set to the beta number if using a beta, 0 otherwise
# rc_version    should be set to the RC number if using an RC, 0 otherwise
%global gecko_dir_ver 2
%global alpha_version 0
%global beta_version  0
%global rc_version    0

%global mozappdir         %{_libdir}/%{name}-%{gecko_dir_ver}
%global tarballdir  mozilla-esr10

Summary:        XUL Runtime for Gecko Applications
Summary(ja):    Gecko アプリケーションのための XUL ランタイム
Name:           xulrunner
Version:        10.0.8
Release:        1%{?_dist_release}
URL:            http://developer.mozilla.org/En/XULRunner
License:        MPLv1.1 or GPLv2+ or LGPLv2+
Group:          Applications/Internet
# You can get sources at ftp://ftp.mozilla.org/pub/firefox/releases/%{version}/source
Source0:        %{name}-%{version}esr.source.tar.bz2
Source10:       %{name}-mozconfig-vine
Source12:       %{name}-redhat-default-prefs.js
Source21:       %{name}.sh.in

# build patches
Patch0:         xulrunner-version.patch
Patch1:         mozilla-build.patch
Patch14:        xulrunner-2.0-chromium-types.patch
Patch17:	xulrunner-10.0-gcc47.patch


# Fedora specific patches
Patch20:        mozilla-193-pkgconfig.patch
Patch23:        wmclass.patch
Patch24:        crashreporter-remove-static.patch

# Upstream patches
Patch38:        mozilla-696393.patch
# https://bugzilla.mozilla.org/show_bug.cgi?id=707993
Patch39:        xulrunner-8.0-fix-maemo-checks-in-npapi.patch
Patch40:        mozilla-682832-proxy.patch
# cherry-picked from 13afcd4c097c
Patch41:        xulrunner-9.0-secondary-build-fix.patch
Patch42:        mozilla-706724.patch
Patch43:        mozilla-file.patch
# Needed to detect/use libvpx-1.0.0
# https://bugzilla.mozilla.org/show_bug.cgi?id=722127
Patch44:	mozilla-722127.patch
Patch46:	mozilla-724615.patch
Patch47:	mozilla-691898.patch

# ---------------------------------------------------

BuildRequires:  nspr-devel >= %{nspr_version}
BuildRequires:  nss-devel >= %{nss_version}
BuildRequires:  cairo-devel >= %{cairo_version}
BuildRequires:  libpng-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  zip
BuildRequires:  bzip2-devel
BuildRequires:  zlib-devel
BuildRequires:  libIDL-devel
BuildRequires:  gtk2-devel
BuildRequires:  krb5-devel
BuildRequires:  pango-devel
BuildRequires:  freetype2-devel >= %{freetype_version}
BuildRequires:  libXt-devel
BuildRequires:  libXrender-devel
BuildRequires:  startup-notification-devel
BuildRequires:  alsa-lib-devel
BuildRequires:  libnotify-devel >= %{libnotify_version}
BuildRequires:  mesa-libGL-devel
BuildRequires:  curl-devel
BuildRequires:  yasm

Requires:       nspr
Requires:       nss
Provides:       gecko-libs = %{gecko_verrel}
Conflicts:      firefox < 3.6

Vendor: Project Vine
Distribution: Vine Linux
Packager: daisuke

%description
XULRunner is a Mozilla runtime package that can be used to bootstrap XUL+XPCOM
applications that are as rich as Firefox and Thunderbird. It provides mechanisms
for installing, upgrading, and uninstalling these applications. XULRunner also
provides libxul, a solution which allows the embedding of Mozilla technologies
in other projects and products.

%package devel
Summary: Development files for Gecko
Summary(ja):  Geckoの開発ファイル
Group: Development/Libraries
Obsoletes: mozilla-devel < 1.9
Obsoletes: firefox-devel < 2.1
Obsoletes: xulrunner-devel-unstable
Provides: gecko-devel = %{gecko_verrel}
Provides: gecko-devel-unstable = %{gecko_verrel}

Requires: xulrunner = %{version}-%{release}
Requires: nspr-devel
Requires: nss-devel
Requires: cairo-devel
Requires: libjpeg-devel
Requires: zip
Requires: bzip2-devel
Requires: zlib-devel
Requires: libIDL-devel
Requires: gtk2-devel
Requires: krb5-devel
Requires: pango-devel
Requires: freetype-devel
Requires: libXt-devel
Requires: libXrender-devel
Requires: startup-notification-devel
Requires: alsa-lib-devel
Requires: libnotify-devel
Requires: mesa-libGL-devel

%description devel
This package contains the libraries amd header files that are needed
for writing XUL+XPCOM applications with Mozilla XULRunner and Gecko.

#---------------------------------------------------------------------

%prep
%setup -q -c
cd %{tarballdir}

sed -e 's/__RPM_VERSION_INTERNAL__/%{gecko_dir_ver}/' %{P:%%PATCH0} \
    > version.patch
%{__patch} -p1 -b --suffix .version --fuzz=0 < version.patch

%patch1  -p2 -b .build
%patch14 -p1 -b .chromium-types
%patch17 -p1 -b .gcc47

%patch20 -p2 -b .pk
%patch23 -p1 -b .wmclass
%patch24 -p1 -b .static

%patch38 -p2 -b .696393
%patch39 -p1 -b .707993
%patch40 -p2 -b .682832
%patch41 -p2 -b .secondary-build
%patch42 -p1 -b .706724
%patch43 -p1 -b .file
%patch44 -p2 -b .vpx1.0.0
%patch46 -p1 -b .724615
%patch47 -p1 -b .691898

%{__rm} -f .mozconfig
%{__cp} %{SOURCE10} .mozconfig

echo "ac_add_options --disable-system-sqlite" >> .mozconfig

%ifarch armv7hl
echo "ac_add_options --with-arch=armv7-a" >> .mozconfig
echo "ac_add_options --with-float-abi=hard" >> .mozconfig
echo "ac_add_options --with-fpu=vfpv3-d16" >> .mozconfig
echo "ac_add_options --disable-elf-hack" >> .mozconfig
%endif
%ifarch armv7hnl
echo "ac_add_options --with-arch=armv7-a" >> .mozconfig
echo "ac_add_options --with-float-abi=hard" >> .mozconfig
echo "ac_add_options --with-fpu=neon" >> .mozconfig
echo "ac_add_options --disable-elf-hack" >> .mozconfig
%endif
%ifarch armv5tel
echo "ac_add_options --with-arch=armv5te" >> .mozconfig
echo "ac_add_options --with-float-abi=soft" >> .mozconfig
echo "ac_add_options --disable-elf-hack" >> .mozconfig
%endif

%ifnarch %{ix86} x86_64
echo "ac_add_options --disable-methodjit" >> .mozconfig
echo "ac_add_options --disable-monoic" >> .mozconfig
echo "ac_add_options --disable-polyic" >> .mozconfig
echo "ac_add_options --disable-tracejit" >> .mozconfig
%endif

#---------------------------------------------------------------------

%build
cd %{tarballdir}

# -fpermissive is needed to build with gcc 4.6+ which has become stricter
# 
# Mozilla builds with -Wall with exception of a few warnings which show up
# everywhere in the code; so, don't override that.
#
# Disable C++ exceptions since Mozilla code is not exception-safe
#
MOZ_OPT_FLAGS=$(echo "$RPM_OPT_FLAGS -fpermissive" | \
                      %{__sed} -e 's/-Wall//' -e 's/-fexceptions/-fno-exceptions/g')
export CFLAGS=$MOZ_OPT_FLAGS
export CXXFLAGS=$MOZ_OPT_FLAGS

export PREFIX='%{_prefix}'
export LIBDIR='%{_libdir}'

MOZ_SMP_FLAGS=-j1
# On x86 architectures, Mozilla can build up to 4 jobs at once in parallel,
# however builds tend to fail on other arches when building in parallel.
%ifarch %{ix86} x86_64
[ -z "$RPM_BUILD_NCPUS" ] && \
     RPM_BUILD_NCPUS="`/usr/bin/getconf _NPROCESSORS_ONLN`"
[ "$RPM_BUILD_NCPUS" -ge 2 ] && MOZ_SMP_FLAGS=-j2
[ "$RPM_BUILD_NCPUS" -ge 4 ] && MOZ_SMP_FLAGS=-j4
%endif

make -f client.mk build STRIP="/bin/true" MOZ_MAKE_FLAGS="$MOZ_SMP_FLAGS" MOZ_SERVICES_SYNC="1"

#---------------------------------------------------------------------

%install
cd %{tarballdir}

# set up our prefs before install, so it gets pulled in to omni.jar
%{__cp} -p %{SOURCE12} dist/bin/defaults/pref/all-redhat.js

DESTDIR=$RPM_BUILD_ROOT make install

# Start script install
%{__rm} -rf $RPM_BUILD_ROOT%{_bindir}/%{name}
%{__cat} %{SOURCE21} | %{__sed} -e 's,XULRUNNER_VERSION,%{gecko_dir_ver},g' > \
  $RPM_BUILD_ROOT%{_bindir}/%{name}
%{__chmod} 755 $RPM_BUILD_ROOT%{_bindir}/%{name}

%{__rm} -f $RPM_BUILD_ROOT%{mozappdir}/%{name}-config

# Copy pc files (for compatibility with 1.9.1)
%{__cp} $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul.pc \
        $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul-unstable.pc
%{__cp} $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul-embedding.pc \
        $RPM_BUILD_ROOT/%{_libdir}/pkgconfig/libxul-embedding-unstable.pc

# Fix multilib devel conflicts...
function install_file() {
genheader=$*
mv ${genheader}.h ${genheader}%{__isa_bits}.h
cat > ${genheader}.h << EOF
/* This file exists to fix multilib conflicts */
#if defined(__x86_64__) || defined(__ia64__) || defined(__s390x__) || defined(__powerpc64__) || (defined(__sparc__) && defined(__arch64__))
#include "${genheader}64.h"
#else
#include "${genheader}32.h"
#endif
EOF
}

INTERNAL_APP_NAME=%{name}-%{gecko_dir_ver}

pushd $RPM_BUILD_ROOT/%{_includedir}/${INTERNAL_APP_NAME}
install_file "mozilla-config"
install_file "js-config"
popd

# Link libraries in sdk directory instead of copying them:
pushd $RPM_BUILD_ROOT%{_libdir}/%{name}-devel-%{gecko_dir_ver}/sdk/lib
for i in *.so; do
     rm $i
     ln -s %{mozappdir}/$i $i
done
popd

# Library path
LD_SO_CONF_D=%{_sysconfdir}/ld.so.conf.d
LD_CONF_FILE=xulrunner-%{__isa_bits}.conf

%{__mkdir_p} ${RPM_BUILD_ROOT}${LD_SO_CONF_D}
%{__cat} > ${RPM_BUILD_ROOT}${LD_SO_CONF_D}/${LD_CONF_FILE} << EOF
%{mozappdir}
EOF

# Copy over the LICENSE
%{__install} -p -c -m 644 LICENSE $RPM_BUILD_ROOT%{mozappdir}

# ghost files
%{__mkdir_p} $RPM_BUILD_ROOT%{mozappdir}/components
touch $RPM_BUILD_ROOT%{mozappdir}/components/compreg.dat
touch $RPM_BUILD_ROOT%{mozappdir}/components/xpti.dat

#---------------------------------------------------------------------

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%preun
# is it a final removal?
if [ $1 -eq 0 ]; then
  %{__rm} -rf %{mozappdir}/components
fi

%files
%defattr(-,root,root,-)
%{_bindir}/xulrunner
%dir %{mozappdir}
%doc %attr(644, root, root) %{mozappdir}/LICENSE
%doc %attr(644, root, root) %{mozappdir}/README.txt
%{mozappdir}/chrome
%{mozappdir}/chrome.manifest
%{mozappdir}/dictionaries
%dir %{mozappdir}/components
%ghost %{mozappdir}/components/compreg.dat
%ghost %{mozappdir}/components/xpti.dat
%{mozappdir}/components/*.so
%{mozappdir}/components/*.manifest
%{mozappdir}/omni.ja
%{mozappdir}/plugins
%{mozappdir}/*.so
%{mozappdir}/mozilla-xremote-client
%{mozappdir}/run-mozilla.sh
%{mozappdir}/xulrunner
%{mozappdir}/xulrunner-bin
%{mozappdir}/xulrunner-stub
%{mozappdir}/platform.ini
%{mozappdir}/dependentlibs.list
%{_sysconfdir}/ld.so.conf.d/xulrunner*.conf
%{mozappdir}/plugin-container

%files devel
%defattr(-,root,root,-)
%dir %{_libdir}/%{name}-devel-*
%{_datadir}/idl/%{name}*%{gecko_dir_ver}
%{_includedir}/%{name}*%{gecko_dir_ver}
%{_libdir}/%{name}-devel-*/*
%{_libdir}/pkgconfig/*.pc
%{mozappdir}/xpcshell

#---------------------------------------------------------------------

%changelog
* Wed Oct 10 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 10.0.8-1
- update to 10.0.8esr

* Sat Jul 14 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 10.0.6-1
- update to 10.0.6 (based on firefox-10.0.6esr source)

* Wed Mar 14 2012 Daisuke SUZUKI <daisuke@linux.or.jp> 10.0.3-1
- update to 10.0.3 (based on firefox-10.0.3esr source)
- clean up spec

* Sun Aug 14 2011 Yoji TOYODA <bsyamato@sea.plala.or.jp> 2.0.1-3
- rebuild with libnotify-0.7

* Tue May 31 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.0.1-2
- modify gre.conf to promote internal gecko version.

* Mon May 23 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.0.1-1
- update to 2.0.1 (sync with firefox-4.0.1)

* Wed Mar 30 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 2.0-1
- update to 2.0 (sync with firefox-4.0)
- BR: libjpeg-turbo-devel >= 1.1.0
- BR: nspr-devel >= 4.8.7
- BR: nss-devel >= 3.12.9
- BR: cairo-devel >= 1.10.2-2
- add Patch130 to use omni.jar (upstream patch)

* Thu Mar 10 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.15-1
- update to 1.9.2.15 (sync with firefox-3.6.15)

* Wed Mar 02 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.14-1
- update to 1.9.2.14 (sync with firefox-3.6.14)

* Sat Jan 08 2011 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.13-1
- update to 1.9.2.13 (sync with firefox-3.6.13)

* Thu Oct 21 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.11-1
- update to 1.9.2.11 (sync with firefox-3.6.11)

* Thu Sep 23 2010 Yoji TOYODA <bsyamato@sea.plala.or.jp> 1.9.2.9-2
- rebuild with rpm-4.8.1 for pkg-config file

* Mon Sep 13 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.9-1
- update to 1.9.2.9 (sync with firefox-3.6.9)
- add patch10 to build with libjpeg-turbo
- build with sqlite-3.7.2
- BR: nspr >= 4.8.6

* Mon Jul 26 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.8-1
- update tp 1.9.2.8 (sync with firefox-3.6.8)

* Wed Jul 21 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.7-1
- update tp 1.9.2.7 (sync with firefox-3.6.7)

* Wed Jun 23 2010 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 1.9.2.4-2
- enable ipc only on ix86/x86_64 arches

* Wed Jun 23 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.4-1
- update to 1.9.2.4 (sync with firefox-3.6.4)
- add patch10 to fix build failure

* Sat Apr 03 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.3-1
- update to 1.9.2.3 (sync with firefox-3.6.3)

* Fri Apr 02 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2.2-1
- update to 1.9.2.2 (sync with firefox-3.6.2)
- add patch7,9 for fix build failure

* Sat Jan 23 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2-3
- enable libnotify support
  - add ac_add_options --enable-libnotify
- disable Necko wifi monitor
  - add ac_add_options --disable-necko-wifi
  - remove BR: wireless-tools-devel
- fix %%files devel
- add patch3,5 to fix jemalloc alignment assertion
- add Patch8 to fix mozilla-plugin.pc

* Sat Jan 23 2010 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 1.9.2-2
- add BR: libnotify-devel, wireless-tools-devel

* Thu Jan 21 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.2-1
- update to 1.9.2 (sync with firefox-3.6)
- obsoletes xulrunner-devel-unstable

* Sat Jan 16 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.7-2
- use internal sqlite3 on vine5

* Fri Jan 08 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.7-1
- update to 1.9.1.7

* Tue Jan 05 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.6-1
- update to 1.9.1.6
- build with sqlite3-3.6.21

* Sat Nov 21 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.5-1
- update to 1.9.1.5

* Sun Oct 18 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.3-1
- update to 1.9.1.3

* Fri Aug 07 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.2-2
- really update to 1.9.1.2 (<BTS:0748>)

* Wed Aug 05 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.2-1
- update to 1.9.1.2 (sync with firefox-3.5.2)

* Sun Jul 19 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1.1-1
- update to 1.9.1.1 (sync with firefox-3.5.1)
- add missing Requires to -devel
- add missing BR

* Wed Jul 01 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1-2
- enable-system-cairo

* Tue Jun 30 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1-1
- update to 1.9.1 (based on firefox 3.5)

* Tue Jun 30 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1-0.2.rc3
- update to 1.9.1rc3 (sync with firefox 3.5rc3)

* Sun Jun 21 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.1-0.1.rc2
- update to xulrunner 1.9.1rc2 (based on firefox 3.5rc2)
- remove old patches
- require nspr >= 4.8

* Fri Jun 12 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.11-1
- new upstream release

* Sun May 03 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.10-2
- update mozconfig
  - disable-system-cairo for stability

* Tue Apr 28 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.10-1
- new upstream release

* Sun Apr 26 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.9-1
- new upstream release
- add ja locale

* Sun Mar 22 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.7-1
- new upstream release

* Thu Oct 02 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.3-1
- new upstream release

* Fri Sep 26 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.2-2
- add Patch3

* Fri Sep 26 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.2-1
- update to xulrunner 1.9.0.2 byild 6
- build with gnome-2.24

* Fri Aug 22 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9.0.1-1
- new upstream release

* Sun Jun 22 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 1.9-1
- initial build for Vine Linux

* Tue Jun 17 2008 Christopher Aillon <caillon@redhat.com> 1.9-1
- Update to 1.9 final

* Thu May 29 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.63
- Simplify PS/PDF operators

* Thu May 22 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.62
- Upstream patch to fsync() less

* Thu May 08 2008 Colin Walters <walters@redhat.com> 1.9-0.61
- Ensure we enable startup notification; add BR and modify config
  (bug #445543)

* Wed Apr 30 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.60
- Some files moved to mozilla-filesystem; kill them and add the Req

* Mon Apr 28 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.59
- Clean up the %%files list and get rid of the executable bit on some files

* Sat Apr 26 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.58
- Fix font scaling

* Fri Apr 25 2008 Martin Stransky <stransky@redhat.com> 1.9-0.57
- Enabled phishing protection (#443403)

* Wed Apr 23 2008 Martin Stransky <stransky@redhat.com> 1.9-0.56
- Changed "__ppc64__" to "__powerpc64__", 
  "__ppc64__" doesn't work anymore
- Added fix for #443725 - Critical hanging bug with fix 
  available upstream (mozbz#429903)

* Fri Apr 18 2008 Martin Stransky <stransky@redhat.com> 1.9-0.55
- Fixed multilib issues, added starting script instead of a symlink
  to binary (#436393)

* Sat Apr 12 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.54
- Add upstream patches for dpi, toolbar buttons, and invalid keys
- Re-enable system cairo

* Mon Apr  7 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.53
- Spec cleanups

* Wed Apr  2 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.52
- Beta 5

* Mon Mar 31 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.51
- Beta 5 RC2

* Thu Mar 27 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.50
- Update to latest trunk (2008-03-27)

* Wed Mar 26 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.49
- Update to latest trunk (2008-03-26)

* Tue Mar 25 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.48
- Update to latest trunk (2008-03-25)

* Mon Mar 24 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.47
- Update to latest trunk (2008-03-24)

* Thu Mar 20 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.46
- Update to latest trunk (2008-03-20)

* Mon Mar 17 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.45
- Update to latest trunk (2008-03-17)

* Mon Mar 17 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.44
- Revert to trunk from the 15th to fix crashes on HTTPS sites

* Sun Mar 16 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.43
- Update to latest trunk (2008-03-16)
- Add patch to negate a11y slowdown on some pages (#431162)

* Sat Mar 15 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.42
- Update to latest trunk (2008-03-15)

* Sat Mar 15 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.41
- Avoid conflicts between gecko debuginfo packages

* Wed Mar 12 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.40
- Update to latest trunk (2008-03-12)

* Tue Mar 11 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.39
- Update to latest trunk (2008-03-11)

* Mon Mar 10 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.38
- Update to latest trunk (2008-03-10)

* Sun Mar  9 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.37
- Update to latest trunk (2008-03-09)

* Fri Mar  7 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta4.36
- Update to latest trunk (2008-03-07)

* Thu Mar  6 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta4.35
- Update to latest trunk (2008-03-06)

* Tue Mar  4 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta4.34
- Update to latest trunk (2008-03-04)

* Sun Mar  2 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.33
- Update to latest trunk (2008-03-02)

* Sat Mar  1 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.32
- Update to latest trunk (2008-03-01)

* Fri Feb 29 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.31
- Update to latest trunk (2008-02-29)

* Thu Feb 28 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.30
- Update to latest trunk (2008-02-28)

* Wed Feb 27 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.29
- Update to latest trunk (2008-02-27)

* Tue Feb 26 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.28
- Update to latest trunk (2008-02-26)

* Sat Feb 23 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.27
- Update to latest trunk (2008-02-23)

* Fri Feb 22 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.26
- Update to latest trunk (2008-02-22)

* Thu Feb 21 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.25
- Update to latest trunk (2008-02-21)

* Wed Feb 20 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.24
- Update to latest trunk (2008-02-20)

* Sun Feb 17 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.23
- Update to latest trunk (2008-02-17)

* Fri Feb 15 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.22
- Update to latest trunk (2008-02-15)

* Thu Feb 14 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta3.21
- Update to latest trunk (2008-02-14)
- Use system hunspell

* Mon Feb 11 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.19
- Update to latest trunk (2008-02-11)

* Mon Feb 11 2008 Adam Jackson <ajax@redhat.com> 1.9-0.beta2.19
- STRIP="/bin/true" on the %%make line so xulrunner-debuginfo contains,
  you know, debuginfo.

* Sun Feb 10 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.18
- Update to latest trunk (2008-02-10)

* Sat Feb  9 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.17
- Update to latest trunk (2008-02-09)

* Wed Feb  6 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.16
- Update to latest trunk (2008-02-06)

* Tue Jan 29 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.15
- Update to latest trunk (2008-01-30)

* Wed Jan 25 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.14
- rebuild agains new nss
- enabled gnome vfs

* Wed Jan 23 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.13
- fixed stable pkg-config files (#429654)
- removed sqlite patch

* Mon Jan 21 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.12
- Update to latest trunk (2008-01-21)

* Tue Jan 15 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.11
- Update to latest trunk (2008-01-15)
- Now with system extensions directory support

* Sat Jan 13 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.10
- Update to latest trunk (2008-01-13)
- Use CFLAGS instead of configure arguments
- Random cleanups: BuildRequires, scriptlets, prefs, etc.

* Sat Jan 12 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.9
- Provide gecko-devel-unstable as well

* Wed Jan 9 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.8
- divided devel package to devel and devel-unstable

* Mon Jan 7 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.7
- removed fedora specific pkg-config files
- updated to the latest trunk (2008-01-07)
- removed unnecessary patches
- fixed idl dir (#427965)

* Thu Jan 3 2008 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.6
- Re-enable camellia256 support now that NSS supports it

* Thu Jan 3 2008 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.5
- updated to the latest trunk (2008-01-03)

* Mon Dec 24 2007 Christopher Aillon <caillon@redhat.com> 1.9-0.beta2.4
- Don't Provide webclient (xulrunner is not itself a webclient)
- Don't Obsolete old firefox, only firefox-devel
- Kill legacy obsoletes (phoenix, etc) that were never in rawhide

* Thu Dec 21 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.3
- added java and plugin subdirs to plugin includes

* Thu Dec 20 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.2
- dependency fixes, obsoletes firefox < 3 and firefox-devel now

* Wed Dec 12 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta2.1
- updated to Beta 2.
- moved SDK to xulrunner-sdk

* Thu Dec 06 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.4
- fixed mozilla-plugin.pc (#412971)

* Tue Nov 27 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.3
- export /etc/gre.d/gre.conf (it's used by python gecko applications)

* Mon Nov 26 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.2
- added xulrunner/js include dir to xulrunner-js

* Tue Nov 20 2007 Martin Stransky <stransky@redhat.com> 1.9-0.beta1.1
- update to beta 1

* Mon Nov 19 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.6
- packed all gecko libraries (#389391)

* Thu Nov 15 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.5
- registered xulrunner libs system-wide
- added xulrunner-gtkmozembed.pc

* Wed Nov 14 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.4
- added proper nss/nspr dependencies

* Wed Nov 14 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.3
- more build fixes, use system nss libraries

* Tue Nov 6 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.2
- build fixes

* Tue Oct 30 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha9.1
- updated to the latest trunk

* Thu Sep 20 2007 David Woodhouse <dwmw2@infradead.org> 1.9-0.alpha7.4
- build fixes for ppc/ppc64

* Tue Sep 20 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha7.3
- removed conflicts with the current gecko-based apps
- added updated ppc64 patch

* Tue Sep 18 2007 Martin Stransky <stransky@redhat.com> 1.9-0.alpha7.2
- build fixes

* Wed Sep  5 2007 Christopher Aillon <caillon@redhat.com> 1.9-0.alpha7.1
- Initial cut at XULRunner 1.9 Alpha 7
- Temporarily revert camellia 256 support since our nss doesn't support it yet
